@@ -1,7 +1,9 @@
-__version__ = "0.1.2"
+__version__ = "0.1.5"
 from . import \
     dataclassutil,exceptions,types,\
     room,member,members,\
     irucaapi,httpirucaapi,memberupdate,\
     irucaclient
-    
\ No newline at end of file
+from .irucaapi import IrucaAPI
+from .httpirucaapi import HTTPIrucaAPI
+from .irucaclient import IrucaClient
\ No newline at end of file
