@@ -9,7 +9,7 @@ def from_json_maybe(json_text: str) -> Optional[member.Member]:
         obj = []
         data = json.loads(json_text)
         for member_data in data:
-            member_obj_maybe = dataclassutil.from_data_maybe(member_data, member.Member)
+            member_obj_maybe = member.from_json_object_maybe(member_data)
             if member_obj_maybe is not None:
                 obj.append(member_obj_maybe)
         return obj
